<?php if ( ! defined('ABSPATH') ) exit;

class GFParsi_IranCities {

	public $province = array();

	public function __construct() {
	
		add_filter('gform_address_types'			, array( $this, 'iran_address' ) );
        add_filter('gform_predefined_choices'		, array( $this, 'predefined_choices' ),1);	
		
		add_filter('gform_field_content' 			, array( $this, 'city_select'), 10, 5);	
		
		add_action('gform_register_init_scripts'	, array( $this, 'init_script') , 10 ,1 );
		add_action('gform_enqueue_scripts'			, array( $this, 'external_js') , 10 , 2 );
		
		add_filter('gform_tooltips'					, array( $this, 'tooltips'));
		add_action('gform_editor_js'				, array( $this, 'iran_cities'));
		add_action('gform_field_standard_settings'	, array( $this, 'iran_cities_option'), 10, 2);
	}
	
	public function tooltips( $tooltips ) {
		$tooltips['gform_activate_iran_cities'] = __('<h6>فعالسازی شهر های ایرانی</h6>برای فعالسازی انتخابگر لیست شهر های ایران می بایست نوع آدرس بر روی "ایران" باشد.', 'GF_FA');
		return $tooltips;
	}
	
	public function get_province() {
		
		$this->province = array(
			__( 'Azarbaijan - East' , 'GF_FA' ),
			__( 'Azarbaijan - West' , 'GF_FA' ),
			__( 'Ardabil'		    , 'GF_FA' ),
			__( 'Isfahan'			, 'GF_FA' ),
			__( 'Alborz'			, 'GF_FA' ),
			__( 'Ilam'				, 'GF_FA' ),
			__( 'Bushehr'			, 'GF_FA' ),
			__( 'Tehran'			, 'GF_FA' ),
			__( 'Chahar Mahaal and Bakhtiari', 'GF_FA' ),
			__( 'Khorasan - South'	, 'GF_FA' ),
			__( 'Khorasan - Razavi'	, 'GF_FA' ),
			__( 'Khorasan - North'	, 'GF_FA' ),
			__( 'Khuzestan'			, 'GF_FA' ),
			__( 'Zanjan'			, 'GF_FA' ),
			__( 'Semnan'			, 'GF_FA' ),
			__( 'Sistan and Baluchistan', 'GF_FA' ),
			__( 'Fars'				, 'GF_FA' ),
			__( 'Qazvin'			, 'GF_FA' ),
			__( 'Qom'				, 'GF_FA' ),
			__( 'Kurdistan'			, 'GF_FA' ),
			__( 'Kerman'			, 'GF_FA' ),
			__( 'Kermanshah'		, 'GF_FA' ),
			__( 'Kohgiluyeh and Boyer-Ahmad', 'GF_FA' ),
			__( 'Golestan'			, 'GF_FA' ),
			__( 'Guilan'			, 'GF_FA' ),
			__( 'Lorestan'			, 'GF_FA' ),
			__( 'Mazandaran'		, 'GF_FA' ),
			__( 'Markazi'			, 'GF_FA' ),
			__( 'Hormozgān'			, 'GF_FA' ),
			__( 'Hamadan'			, 'GF_FA' ),
			__( 'Yazd'				, 'GF_FA' )
		);
	}
	
	public function iran_address( $address_types ) {
		$this->get_province();
		$address_types['iran'] = array(
			'label'       => __( 'Iran', 'GF_FA' ),
			'country'     => __( 'Iran', 'GF_FA' ),
			'zip_label'   => __( 'Postal Code', 'GF_FA' ),
			'state_label' => __( 'Province', 'GF_FA' ),
			'states'      => array_merge( array('') , $this->province )
		);
		return $address_types;
	}
	
	public function predefined_choices($choices){
		$this->get_province();
		$states[__( 'Provinces of Iran', 'GF_FA' )] = $this->province;	
		return $choices = array_merge( $states, $choices);
	}
	
	public function iran_cities(){ ?>
		
		<script type='text/javascript'>
			fieldSettings["address"] += ", .iran_cities";
			jQuery(document).bind("gform_load_field_settings", function(event, field, form){
				jQuery("#iran_cities").attr("checked", field["iran_cities"] == true);
			});
		</script>
		
		<?php
	}
	
	public function iran_cities_option( $position, $form_id ){
		
		if( $position == 25 ) { ?>
		
			<li class="iran_cities field_setting">
				<input type="checkbox" id="iran_cities" onclick="SetFieldProperty('iran_cities', jQuery(this).is(':checked') ? 1 : 0);"/> 
				<label class="inline gfield_value_label" for="iran_cities" class="inline">
					<?php _e( 'Activate Iran Cities', 'GF_FA' ); ?>
					<?php gform_tooltip("gform_activate_iran_cities") ?>
				</label>
			</li>
		
		<?php	
		}	
	}
		
	public function city_select( $content, $field, $value, $lead_id, $form_id ){
	
		if ( $field['type'] == 'address' && $field['addressType'] == 'iran' && rgget("iran_cities", $field) && ! is_admin() ) {
			
			$id = $field['id'];

			preg_match( "/<input type='text' name='input_{$id}.3'(.*?)\/>/",  $content, $match );
			
			if ( !empty($match[0]) && !empty($match[1]) ) {
				$city_input = str_replace( "value=''" , "", $match[1]);
				$content = str_replace( $match[0] , "<select name='input_{$id}.3' {$city_input} ><option value='' selected='selected'>&nbsp;&nbsp;</option></select>", $content );
				return $content;
			}
		}

		return $content;
	}
	
	public function external_js( $form , $ajax ) {
		
		$fields = GFCommon::get_fields_by_type( $form, array( 'address' ) );
		
		foreach ( (array) $fields as $field ) {
			
			if ( $field['type'] == 'address' && $field['addressType'] == 'iran' && rgget("iran_cities", $field) && ! is_admin() ) {
				
				wp_dequeue_script('gform_iran_citeis');
				wp_deregister_script('gform_iran_citeis');
				
				wp_register_script( 'gform_iran_citeis', GF_PARSI_URL . 'assets/js/iran-cities-sorted.min.js', array() , GF_PARSI_VERSION, false );
				wp_enqueue_script(  'gform_iran_citeis' );
			}
		}
	}
	
	public function init_script( $form ) {
    
		foreach( $form['fields'] as &$field ) {
			
			if ( $field['type'] == 'address' && $field['addressType'] == 'iran' && rgget("iran_cities", $field) && ! is_admin() ) {
					
				$field_id = $field['id'];
				$form_id = $form['id'];
				$id = $form_id . '_'. $field_id;

				$script = '(function($){' .
					'$(".ginput_container_address #input_' . $id . '_4").each(function(){' .
						'$(".ginput_container_address #input_' . $id . '_3").empty();' .
						'$(".ginput_container_address #input_' . $id . '_3").append(gform_iranCities($(".ginput_container_address #input_' . $id . '_4").val()));' .
					'}).change(function(){' .
						'$(".ginput_container_address #input_' . $id . '_3").empty();' .
						'$(".ginput_container_address #input_' . $id . '_3").append(gform_iranCities($(".ginput_container_address #input_' . $id . '_4").val()));' .	
					'});' .
				'})(jQuery);';
    
				GFFormDisplay::add_init_script( $form['id'], 'iran_address_city_' . $id, GFFormDisplay::ON_PAGE_RENDER, $script );

			}
		}
	}

}

new GFParsi_IranCities();